==============
``vcd.writer``
==============

.. automodule:: vcd.writer

.. autoclass:: VCDPhaseError
   :members:

.. autoclass:: VCDWriter
   :members:

.. autoclass:: Variable
   :members:

.. autoclass:: ScalarVariable
   :members:

.. autoclass:: RealVariable
   :members:

.. autoclass:: VectorVariable
   :members:

.. autoclass:: CompoundVectorVariable
   :members:
